# VMDataCenter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**disk_pool_pricing** | [**list[DiskStoragePriceHr]**](DiskStoragePriceHr.md) |  | [optional] 
**id** | **str** |  | 
**ipv4_price_hr** | [**Decimal**](Decimal.md) |  | [optional] 
**network_pricing** | [**list[NetworkPriceHr]**](NetworkPriceHr.md) |  | [optional] 
**region_id** | **str** |  | 
**renewable_energy** | **bool** |  | 
**supplier_name** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


